# Lomapy

[![Version](https://img.shields.io/pypi/v/lomapy.svg?style=flat)](https://pypi.python.org/pypi/lomapy)
[![Python Version](https://img.shields.io/pypi/pyversions/lomapy?style=flat)](https://pypi.python.org/pypi/lomapy)
[![License](https://img.shields.io/github/license/AlanTaranti/Lomapy)](LICENSE)
[![Documentação](https://readthedocs.org/projects/lomapy/badge/?version=latest)](https://lomapy.readthedocs.io/en/latest/?badge=latest)
[![Build](https://travis-ci.org/AlanTaranti/Lomapy.svg?branch=master)](https://travis-ci.org/AlanTaranti/Lomapy)
[![Coverage Status](https://coveralls.io/repos/github/AlanTaranti/Lomapy/badge.svg?branch=master)](https://coveralls.io/github/AlanTaranti/Lomapy?branch=master)

## O que é esse o projeto?

É uma biblioteca **não oficial** que disponibiliza um interface em python para a API de Afiliados do Lomadee.
O Lomapy é compatível com versão 3 da API da Lomadee.

## Requisitos

- Python 3.5+
- Linux, Windows, Mac OSX ou BSD

## Como instalar e utilizar esse projeto? 

### Instalação
    
    pip install lomapy
    
### Começo Rápido

Segue um exemplo de como utilizar essa biblioteca.

*Não possui um APP_TOKEN ou SOURCE_ID? Consulte a documentação da [Lomadee](https://developer.lomadee.com/).*

    import lomapy
    
    app_token = {SEU_APP_TOKEN_AQUI}
    source_id = {SEU_SOURCE_ID_AQUI}
    
    lomapy.autenticar(app_token, source_id)
    
    lomapy.categorias.obter_todas()

### Documentação

A documentação está disponível online em [Lomapy Read The Docs](https://lomapy.readthedocs.io/) e no diretório [docs](docs)
    

## Como eu entro em contato?
* Email: [alan.taranti@gmail.com](mailto:alan.taranti@gmail.com)
* Website: <a href="http://alantaranti.github.io" target="_blank">alantaranti.github.io</a>
